EthosTestHelper class

Test utilities for using Ethos inside a dart test or flutter_test suite.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

analyzeProject(String projectPath, {String? configPath}) Future<CoverageReport>
Analyzes the Dart files in projectPath and returns a CoverageReport.
analyzeSource(String source, {String? configPath}) Future<CoverageReport>
Analyzes an inline Dart source snippet and returns a CoverageReport.
expectNoCriticalFailures(String projectPath, {String? configPath}) Future<void>
Asserts that projectPath has no critical accessibility failures.